.. _advanced:

Advanced features
=================

.. include:: include/local-boot-partition-images.rst

.. include:: include/root-device-hints.rst

.. include:: include/kernel-boot-parameters.rst

.. include:: include/boot-mode.rst

.. include:: include/disk-label.rst

.. include:: include/trusted-boot.rst

.. include:: include/notifications.rst

.. include:: include/console.rst
